@@ -8,7 +8,7 @@ iris[, -5] %>%
   ggbiplot(aes(color = species)) +
   theme_bw() +
   scale_color_brewer(type = "qual", palette = 2) +
-  geom_rows_lineranges(fun.data = mean_sdl, size = .75) +
+  geom_rows_lineranges(fun.data = mean_sdl, linewidth = .75) +
   geom_rows_point(alpha = .5) +
   geom_cols_vector(color = "#444444") +
   geom_cols_text_radiate(aes(label = name), color = "#444444", size = 3) +
